(function() {
  'use strict';

  var globals = typeof global === 'undefined' ? self : global;
  if (typeof globals.require === 'function') return;

  var modules = {};
  var cache = {};
  var aliases = {};
  var has = {}.hasOwnProperty;

  var expRe = /^\.\.?(\/|$)/;
  var expand = function(root, name) {
    var results = [], part;
    var parts = (expRe.test(name) ? root + '/' + name : name).split('/');
    for (var i = 0, length = parts.length; i < length; i++) {
      part = parts[i];
      if (part === '..') {
        results.pop();
      } else if (part !== '.' && part !== '') {
        results.push(part);
      }
    }
    return results.join('/');
  };

  var dirname = function(path) {
    return path.split('/').slice(0, -1).join('/');
  };

  var localRequire = function(path) {
    return function expanded(name) {
      var absolute = expand(dirname(path), name);
      return globals.require(absolute, path);
    };
  };

  var initModule = function(name, definition) {
    var hot = hmr && hmr.createHot(name);
    var module = {id: name, exports: {}, hot: hot};
    cache[name] = module;
    definition(module.exports, localRequire(name), module);
    return module.exports;
  };

  var expandAlias = function(name) {
    return aliases[name] ? expandAlias(aliases[name]) : name;
  };

  var _resolve = function(name, dep) {
    return expandAlias(expand(dirname(name), dep));
  };

  var require = function(name, loaderPath) {
    if (loaderPath == null) loaderPath = '/';
    var path = expandAlias(name);

    if (has.call(cache, path)) return cache[path].exports;
    if (has.call(modules, path)) return initModule(path, modules[path]);

    throw new Error("Cannot find module '" + name + "' from '" + loaderPath + "'");
  };

  require.alias = function(from, to) {
    aliases[to] = from;
  };

  var extRe = /\.[^.\/]+$/;
  var indexRe = /\/index(\.[^\/]+)?$/;
  var addExtensions = function(bundle) {
    if (extRe.test(bundle)) {
      var alias = bundle.replace(extRe, '');
      if (!has.call(aliases, alias) || aliases[alias].replace(extRe, '') === alias + '/index') {
        aliases[alias] = bundle;
      }
    }

    if (indexRe.test(bundle)) {
      var iAlias = bundle.replace(indexRe, '');
      if (!has.call(aliases, iAlias)) {
        aliases[iAlias] = bundle;
      }
    }
  };

  require.register = require.define = function(bundle, fn) {
    if (bundle && typeof bundle === 'object') {
      for (var key in bundle) {
        if (has.call(bundle, key)) {
          require.register(key, bundle[key]);
        }
      }
    } else {
      modules[bundle] = fn;
      delete cache[bundle];
      addExtensions(bundle);
    }
  };

  require.list = function() {
    var list = [];
    for (var item in modules) {
      if (has.call(modules, item)) {
        list.push(item);
      }
    }
    return list;
  };

  var hmr = globals._hmr && new globals._hmr(_resolve, require, modules, cache);
  require._cache = cache;
  require.hmr = hmr && hmr.wrap;
  require.brunch = true;
  globals.require = require;
})();

require.define({'src/Easel/index.js': function(exports, require, module) {
  "use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
// import createjs from 'createjs-browserify';
var createjs = window.createjs;

var easel = {
  AlphaMapFilter: createjs.AlphaMapFilter,
  AlphaMaskFilter: createjs.AlphaMaskFilter,
  Bitmap: createjs.Bitmap,
  BitmapText: createjs.BitmapText,
  BlurFilter: createjs.BlurFilter,
  ButtonHelper: createjs.ButtonHelper,
  ColorFilter: createjs.ColorFilter,
  ColorMatrix: createjs.ColorMatrix,
  ColorMatrixFilter: createjs.ColorMatrixFilter,
  Container: createjs.Container,
  DisplayObject: createjs.DisplayObject,
  DisplayProps: createjs.DisplayProps,
  DOMElement: createjs.DOMElement,
  EventDispatcher: createjs.EventDispatcher,
  Filter: createjs.Filter,
  Graphics: createjs.Graphics,
  Matrix2D: createjs.Matrix2D,
  MouseEvent: createjs.MouseEvent,
  MovieClip: createjs.MovieClip,
  MovieClipPlugin: createjs.MovieClipPlugin,
  Point: createjs.Point,
  Rectangle: createjs.Rectangle,
  Shadow: createjs.Shadow,
  Shape: createjs.Shape,
  Sprite: createjs.Sprite,
  SpriteContainer: createjs.SpriteContainer,
  SpriteSheet: createjs.SpriteSheet,
  SpriteSheetBuilder: createjs.SpriteSheetBuilder,
  SpriteSheetUtils: createjs.SpriteSheetUtils,
  SpriteStage: createjs.SpriteStage,
  Stage: createjs.Stage,
  Text: createjs.Text,
  Ticker: createjs.Ticker,
  Touch: createjs.Touch,
  UID: createjs.UID,
  extend: createjs.extend,
  indexOf: createjs.indexOf,
  promote: createjs.promote,
  buildDate: new Date(createjs.EaselJS.buildDate),
  version: createjs.EaselJS.version
};

exports.default = easel;
var AlphaMapFilter = exports.AlphaMapFilter = easel.AlphaMapFilter;
var AlphaMaskFilter = exports.AlphaMaskFilter = easel.AlphaMaskFilter;
var Bitmap = exports.Bitmap = easel.Bitmap;
var BitmapText = exports.BitmapText = easel.BitmapText;
var BlurFilter = exports.BlurFilter = easel.BlurFilter;
var ButtonHelper = exports.ButtonHelper = easel.ButtonHelper;
var ColorFilter = exports.ColorFilter = easel.ColorFilter;
var ColorMatrix = exports.ColorMatrix = easel.ColorMatrix;
var ColorMatrixFilter = exports.ColorMatrixFilter = easel.ColorMatrixFilter;
var Container = exports.Container = easel.Container;
var DisplayObject = exports.DisplayObject = easel.DisplayObject;
var DisplayProps = exports.DisplayProps = easel.DisplayProps;
var DOMElement = exports.DOMElement = easel.DOMElement;
var EventDispatcher = exports.EventDispatcher = easel.EventDispatcher;
var Filter = exports.Filter = easel.Filter;
var Graphics = exports.Graphics = easel.Graphics;
var Matrix2D = exports.Matrix2D = easel.Matrix2D;
var MouseEvent = exports.MouseEvent = easel.MouseEvent;
var MovieClip = exports.MovieClip = easel.MovieClip;
var MovieClipPlugin = exports.MovieClipPlugin = easel.MovieClipPlugin;
var Point = exports.Point = easel.Point;
var Rectangle = exports.Rectangle = easel.Rectangle;
var Shadow = exports.Shadow = easel.Shadow;
var Shape = exports.Shape = easel.Shape;
var Sprite = exports.Sprite = easel.Sprite;
var SpriteContainer = exports.SpriteContainer = easel.SpriteContainer;
var SpriteSheet = exports.SpriteSheet = easel.SpriteSheet;
var SpriteSheetBuilder = exports.SpriteSheetBuilder = easel.SpriteSheetBuilder;
var SpriteSheetUtils = exports.SpriteSheetUtils = easel.SpriteSheetUtils;
var SpriteStage = exports.SpriteStage = easel.SpriteStage;
var Stage = exports.Stage = easel.Stage;
var Text = exports.Text = easel.Text;
var Ticker = exports.Ticker = easel.Ticker;
var Touch = exports.Touch = easel.Touch;
var UID = exports.UID = easel.UID;
var extend = exports.extend = easel.extend;
var indexOf = exports.indexOf = easel.indexOf;
var promote = exports.promote = easel.promote;
var buildDate = exports.buildDate = easel.EaselJS.buildDate;
var version = exports.version = easel.EaselJS.version;


}});


    
require.define({'src/Preload/index.js': function(exports, require, module) {
  "use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
// import createjs from 'createjs-browserify';
var createjs = window.createjs;

var preload = {
  AbstractLoader: createjs.AbstractLoader,
  AbstractMediaLoader: createjs.AbstractMediaLoader,
  AbstractRequest: createjs.AbstractRequest,
  BinaryLoader: createjs.BinaryLoader,
  CSSLoader: createjs.CSSLoader,
  DataUtils: createjs.DataUtils,
  DomUtils: createjs.DomUtils,
  ErrorEvent: createjs.ErrorEvent,
  Event: createjs.Event,
  EventDispatcher: createjs.EventDispatcher,
  ImageLoader: createjs.ImageLoader,
  JavaScriptLoader: createjs.JavaScriptLoader,
  JSONLoader: createjs.JSONLoader,
  JSONPLoader: createjs.JSONPLoader,
  LoadItem: createjs.LoadItem,
  LoadQueue: createjs.LoadQueue,
  ManifestLoader: createjs.ManifestLoader,
  MediaTagRequest: createjs.MediaTagRequest,
  ProgressEvent: createjs.ProgressEvent,
  RequestUtils: createjs.ProgressEvent,
  SamplePlugin: createjs.SamplePlugin,
  SoundLoader: createjs.SoundLoader,
  SpriteSheetLoader: createjs.SpriteSheetLoader,
  SVGLoader: createjs.SVGLoader,
  TagRequest: createjs.TagRequest,
  TextLoader: createjs.TextLoader,
  VideoLoader: createjs.VideoLoader,
  XHRRequest: createjs.XHRRequest,
  XMLLoader: createjs.XMLLoader,
  extend: createjs.extend,
  indexOf: createjs.indexOf,
  promote: createjs.promote,
  buildDate: new Date(createjs.PreloadJS.buildDate),
  version: createjs.PreloadJS.version
};

exports.default = preload;
var AbstractLoader = exports.AbstractLoader = preload.AbstractLoader;
var AbstractMediaLoader = exports.AbstractMediaLoader = preload.AbstractMediaLoader;
var AbstractRequest = exports.AbstractRequest = preload.AbstractRequest;
var BinaryLoader = exports.BinaryLoader = preload.BinaryLoader;
var CSSLoader = exports.CSSLoader = preload.CSSLoader;
var DataUtils = exports.DataUtils = preload.DataUtils;
var DomUtils = exports.DomUtils = preload.DomUtils;
var ErrorEvent = exports.ErrorEvent = preload.ErrorEvent;
var Event = exports.Event = preload.Event;
var EventDispatcher = exports.EventDispatcher = preload.EventDispatcher;
var ImageLoader = exports.ImageLoader = preload.ImageLoader;
var JavaScriptLoader = exports.JavaScriptLoader = preload.JavaScriptLoader;
var JSONLoader = exports.JSONLoader = preload.JSONLoader;
var JSONPLoader = exports.JSONPLoader = preload.JSONPLoader;
var LoadItem = exports.LoadItem = preload.LoadItem;
var LoadQueue = exports.LoadQueue = preload.LoadQueue;
var ManifestLoader = exports.ManifestLoader = preload.ManifestLoader;
var MediaTagRequest = exports.MediaTagRequest = preload.MediaTagRequest;
var ProgressEvent = exports.ProgressEvent = preload.ProgressEvent;
var RequestUtils = exports.RequestUtils = preload.ProgressEvent;
var SamplePlugin = exports.SamplePlugin = preload.SamplePlugin;
var SoundLoader = exports.SoundLoader = preload.SoundLoader;
var SpriteSheetLoader = exports.SpriteSheetLoader = preload.SpriteSheetLoader;
var SVGLoader = exports.SVGLoader = preload.SVGLoader;
var TagRequest = exports.TagRequest = preload.TagRequest;
var TextLoader = exports.TextLoader = preload.TextLoader;
var VideoLoader = exports.VideoLoader = preload.VideoLoader;
var XHRRequest = exports.XHRRequest = preload.XHRRequest;
var XMLLoader = exports.XMLLoader = preload.XMLLoader;
var extend = exports.extend = preload.extend;
var indexOf = exports.indexOf = preload.indexOf;
var promote = exports.promote = preload.promote;
var buildDate = exports.buildDate = preload.PreloadJS.buildDate;
var version = exports.version = preload.PreloadJS.version;


}});


    
require.define({'src/Sound/index.js': function(exports, require, module) {
  "use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
// import createjs from 'createjs-browserify';
var createjs = window.createjs;

var sound = {
  AbstractPlugin: createjs.AbstractPlugin,
  AbstractSoundInstance: createjs.AbstractSoundInstance,
  AudioSprite: createjs.AudioSprite,
  CordovaAudioLoader: createjs.CordovaAudioLoader,
  CordovaAudioPlugin: createjs.CordovaAudioPlugin,
  CordovaAudioSoundInstance: createjs.CordovaAudioSoundInstance,
  ErrorEvent: createjs.ErrorEvent,
  Event: createjs.Event,
  EventDispatcher: createjs.EventDispatcher,
  FlashAudioLoader: createjs.FlashAudioLoader,
  FlashAudioPlugin: createjs.FlashAudioPlugin,
  FlashAudioSoundInstance: createjs.FlashAudioSoundInstance,
  HTMLAudioPlugin: createjs.HTMLAudioPlugin,
  HTMLAudioSoundInstance: createjs.HTMLAudioSoundInstance,
  HTMLAudioTagPool: createjs.HTMLAudioTagPool,
  PlayPropsConfig: createjs.PlayPropsConfig,
  Sound: createjs.Sound,
  WebAudioLoader: createjs.WebAudioLoader,
  WebAudioPlugin: createjs.WebAudioPlugin,
  WebAudioSoundInstance: createjs.WebAudioSoundInstance,
  extend: createjs.extend,
  indexOf: createjs.indexOf,
  promote: createjs.promote,
  buildDate: new Date(createjs.SoundJS.buildDate),
  version: createjs.SoundJS.version
};

exports.default = sound;
var AbstractPlugin = exports.AbstractPlugin = sound.AbstractPlugin;
var AbstractSoundInstance = exports.AbstractSoundInstance = sound.AbstractSoundInstance;
var AudioSprite = exports.AudioSprite = sound.AudioSprite;
var CordovaAudioLoader = exports.CordovaAudioLoader = sound.CordovaAudioLoader;
var CordovaAudioPlugin = exports.CordovaAudioPlugin = sound.CordovaAudioPlugin;
var CordovaAudioSoundInstance = exports.CordovaAudioSoundInstance = sound.CordovaAudioSoundInstance;
var ErrorEvent = exports.ErrorEvent = sound.ErrorEvent;
var Event = exports.Event = sound.Event;
var EventDispatcher = exports.EventDispatcher = sound.EventDispatcher;
var FlashAudioLoader = exports.FlashAudioLoader = sound.FlashAudioLoader;
var FlashAudioPlugin = exports.FlashAudioPlugin = sound.FlashAudioPlugin;
var FlashAudioSoundInstance = exports.FlashAudioSoundInstance = sound.FlashAudioSoundInstance;
var HTMLAudioPlugin = exports.HTMLAudioPlugin = sound.HTMLAudioPlugin;
var HTMLAudioSoundInstance = exports.HTMLAudioSoundInstance = sound.HTMLAudioSoundInstance;
var HTMLAudioTagPool = exports.HTMLAudioTagPool = sound.HTMLAudioTagPool;
var PlayPropsConfig = exports.PlayPropsConfig = sound.PlayPropsConfig;
var Sound = exports.Sound = sound.Sound;
var WebAudioLoader = exports.WebAudioLoader = sound.WebAudioLoader;
var WebAudioPlugin = exports.WebAudioPlugin = sound.WebAudioPlugin;
var WebAudioSoundInstance = exports.WebAudioSoundInstance = sound.WebAudioSoundInstance;
var extend = exports.extend = sound.extend;
var indexOf = exports.indexOf = sound.indexOf;
var promote = exports.promote = sound.promote;
var buildDate = exports.buildDate = sound.SoundJS.buildDate;
var version = exports.version = sound.SoundJS.version;


}});


    
require.define({'src/Tween/index.js': function(exports, require, module) {
  "use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
// import createjs from 'createjs-browserify';
var createjs = window.createjs;

var tween = {
  CSSPlugin: createjs.CSSPlugin,
  Ease: createjs.Ease,
  Event: createjs.Event,
  EventDispatcher: createjs.EventDispatcher,
  MotionGuidePlugin: createjs.MotionGuidePlugin,
  SamplePlugin: createjs.SamplePlugin,
  Ticker: createjs.Ticker,
  Timeline: createjs.Timeline,
  Tween: createjs.Tween,
  extend: createjs.extend,
  indexOf: createjs.indexOf,
  promote: createjs.promote,
  buildDate: new Date(createjs.TweenJS.buildDate),
  version: createjs.TweenJS.version
};

exports.default = tween;
var CSSPlugin = exports.CSSPlugin = tween.CSSPlugin;
var Ease = exports.Ease = tween.Ease;
var Event = exports.Event = tween.Event;
var EventDispatcher = exports.EventDispatcher = tween.EventDispatcher;
var MotionGuidePlugin = exports.MotionGuidePlugin = tween.MotionGuidePlugin;
var SamplePlugin = exports.SamplePlugin = tween.SamplePlugin;
var Ticker = exports.Ticker = tween.Ticker;
var Timeline = exports.Timeline = tween.Timeline;
var Tween = exports.Tween = tween.Tween;
var extend = exports.extend = tween.extend;
var indexOf = exports.indexOf = tween.indexOf;
var promote = exports.promote = tween.promote;
var buildDate = exports.buildDate = tween.TweenJS.buildDate;
var version = exports.version = tween.TweenJS.version;


}});


    
require.define({'src/index.js': function(exports, require, module) {
  'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Sound = exports.Preload = exports.Tween = exports.Easel = undefined;

var _Easel = require('./Easel');

var _Easel2 = _interopRequireDefault(_Easel);

var _Tween = require('./Tween');

var _Tween2 = _interopRequireDefault(_Tween);

var _Preload = require('./Preload');

var _Preload2 = _interopRequireDefault(_Preload);

var _Sound = require('./Sound');

var _Sound2 = _interopRequireDefault(_Sound);

var _release = require('../release');

var _release2 = _interopRequireDefault(_release);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var status = {
  initialized: true,
  modules: {
    EaselJS: {
      version: _Easel2.default.version,
      build: _Easel2.default.buildDate
    },
    TweenJS: {
      version: _Tween2.default.version,
      build: _Tween2.default.buildDate
    },
    PreloadJS: {
      version: _Preload2.default.version,
      build: _Preload2.default.buildDate
    },
    SoundJS: {
      version: _Sound2.default.version,
      build: _Sound2.default.buildDate
    }
  },
  version: _release2.default.version,
  build: _release2.default.build
};

console.log('Create ES6 JS initialized', status);

var create = {
  Easel: _Easel2.default,
  Tween: _Tween2.default,
  Preload: _Preload2.default,
  Sound: _Sound2.default,
  status: status
};

exports.default = create;
var Easel = exports.Easel = create.Easel;
var Tween = exports.Tween = create.Tween;
var Preload = exports.Preload = create.Preload;
var Sound = exports.Sound = create.Sound;


}});


    
//# sourceMappingURL=create-es6.js.map